#!/bin/sh

# Build script for PyAudio
# Author: Ejis <ejis@mailoo.org>

# Homepage: http://people.csail.mit.edu/hubert/pyaudio/


set -e


SOFTNAME=pyaudio
VERSION=0.2.3
ZENVER=64
BUILD=1

MARCH=i486
FLAGS="-O2 -march=$MARCH -mtune=i686"

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/$SOFTNAME-$VERSION
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep
LOG=$PKGDIR.log

SRCFILE=$SOFTNAME-$VERSION.tar.gz
SRCURL='http://people.csail.mit.edu/hubert/pyaudio/packages'

SRCLINKS=($SRCURL/$SRCFILE)

DOC=(
	$SOFTDIR/CHANGELOG
	$SOFTDIR/INSTALL
	$SOFTDIR/README
	$SOFTDIR/docs/*
)

EXTRADEPS=(
)

LESSDEPS=(
	fakeroot
)


# Check for source files and download it if necessary

if [ ! -f $CWD/$SRCFILE ]; then
	wget -c -t 0 -T 50 -w 0 $SRCURL/$SRCFILE
fi


# Erase the previous build files

rm -rf $SOFTDIR $PKGDIR $MD5 $SRC $DEP $LOG
mkdir -p $PKG


# Build

build () {
	
	export CFLAGS=$FLAGS
	export CXXFLAGS=$FLAGS
	
	tar -xvf $CWD/$SRCFILE

	cd $SOFTDIR

	python setup.py install --prefix=/usr --root=$PKGDIR

}


# Packaging

packaging () {
	
	( cd $PKG

	mkdir -p $PKGDIR/install
	mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION
	mkdir -p $PKGDIR/usr/doc/$SOFTNAME-$VERSION


           #|-----handy-ruler------------------------------------------------------|
	cat > $PKGDIR/install/slack-desc <<EOF
$SOFTNAME: $SOFTNAME
$SOFTNAME:
$SOFTNAME: PyAudio provides Python bindings for PortAudio, the cross-platform
$SOFTNAME: audio I/O library. With PyAudio, you can easily use Python to play and
$SOFTNAME: record audio on a variety of platforms.
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME:
EOF

	
	# Redundent
	
	if [ -d $PKGDIR/usr/share/doc ]; then
		mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
		rm -rvf $PKGDIR/usr/share/doc
	fi

	find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
		xargs strip --strip-unneeded 2> /dev/null || true
	find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
		xargs strip --strip-unneeded 2> /dev/null || true

	if [ -d $PKGDIR/usr/man ]; then
		
		( cd $PKGDIR/usr/man
			find . -type f -exec gzip -9 {} \;
			for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
		)
		
	fi

	if [ -d $PKGDIR/usr/info/dir ]; then
		
		rm -f $PKGDIR/usr/info/dir
		gzip -9 $PKGDIR/usr/info/*.info*
		
	fi

	find . -name perllocal.pod \
		-o -name ".packlist" \
		-o -name "*.bs" \
		| xargs rm -f


	cp $CWD/build-$SOFTNAME.sh $PKGDIR/usr/src/$SOFTNAME-$VERSION/

	cp -rf	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


	# fix permissions and ownership
	chown -R root:root .
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 666 -exec chmod 644 {} \;
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;


	/sbin/makepkg -l y -c n $PKGFILE )


	echo 'Creating .md5 file'
	md5sum $PKG.txz >> $MD5

	echo 'Creating .src file'
	for link in ${SRCLINKS[@]}; do
		echo $link >> $SRC
	done

	echo 'Checking for dependencies'
	deps=$(depfinder $PKGFILE)
	
	for dep in ${EXTRADEPS[@]}; do
		deps="$deps,$dep"
	done
	
	for dep in ${LESSDEPS[@]}; do
		deps=${deps/$dep/}
	done
	
	order=$(echo ${deps//,/ } | sort -d)
	echo ${order// /,} >> $DEP
}


LANG=C build | tee $LOG
LANG=C packaging 2>&1 | tee -a $LOG

echo "Removing build directories"
rm -rf $SOFTDIR $PKG
